pub fn setup_logging(max_level: impl Into<LevelFilter>) -> Result<(), Error>Expand description
Sets up logging facilities.
This function first tries to connect to journald socket for logging. Only when that fails a simple logger is used.
Errors
An error is returned if a logger has already been set.