pub enum CertificateType {
OpenPgp,
}Expand description
The type of the certificate that has been generated for the signing key.
Variants
OpenPgp
OpenPGP certificate.
Implementations
Sourceimpl CertificateType
impl CertificateType
Sourcepub fn with_framing(&self, raw_bytes: &[u8]) -> CertificateData
pub fn with_framing(&self, raw_bytes: &[u8]) -> CertificateData
Print raw certificate bytes with correct framing.
For OpenPGP, for example, this is the same as using armor.